from enum import Enum

class Environment(str, Enum):
    sandbox = "sandbox"
    production = "production"

BASE_URLS = {
    Environment.sandbox: "https://checkout-sandbox.payway.com.kh",
    Environment.production: "https://checkout.payway.com.kh"
}



from .qr import (
    Currency,
    PaymentOption,
    PaymentOptions,
    PurchaseType,
    QRImageTemplate,
    QRRequest,
    QRResponse,
    QRStatus,
)
from .check_transaction import(
    CheckTransactionRequest,
    CheckTransactionResponse,
    CheckTransactionData,
    CheckTransactionStatus
)
from .close_transaction import (
    CloseTransactionRequest,
    CloseTransactionResponse,
    CloseTransactionStatus,
)

__all__ = [
    # QR
    "Currency",
    "PaymentOption",
    "PaymentOptions",
    "PurchaseType",
    "QRImageTemplate",
    "QRRequest",
    "QRResponse",
    "QRStatus",

    #Check transaction
    "CheckTransactionRequest",
    "CheckTransactionResponse",
    "CheckTransactionData",
    "CheckTransactionStatus",

    #Close transaction
    "CloseTransactionRequest",
    "CloseTransactionResponse",
    "CloseTransactionStatus",
]
